Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Cache ¶
type Cache struct {
// contains filtered or unexported fields
}
Cache stores arbitrary data with expiration time.
func New ¶
New creates a new cache that asynchronously cleans expired entries after the given time passes.
func (*Cache) Delete ¶ added in v1.0.2
func (cache *Cache) Delete(key interface{})
Delete deletes the key and its value from the cache.
Click to show internal directories.
Click to hide internal directories.